GetData extension

ConstantReader is a very important part of code-generation and we need to get some data and some changes to get the code generated in the best way

on
  • ConstantReader

Properties

getAbstract → bool?

Available on ConstantReader, provided by the GetData extension

no setter
getAs → String?

Available on ConstantReader, provided by the GetData extension

no setter
getFreezed → bool?

Available on ConstantReader, provided by the GetData extension

no setter
getIsExtended → bool?

Available on ConstantReader, provided by the GetData extension

no setter
getName → String?

Available on ConstantReader, provided by the GetData extension

no setter