AddCode class

This class is a standard function to add code in the code generator some parts and function are repetitive, so they should be done in a function especially they will hel in the overall changes in the code-generation

Constructors

AddCode()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

addClass({required String className, required String body, AnnotationTypes? type}) → String
addCommentLine(String? line) → String
addCommentLineList(List lines) → String
addImport(String path) → String
addLine(String? line) → String
addLineList(List lines) → String
addSpace() → String