Prints class

This class has some standard function to print data and information in the terminal it mostly use in the development, pass it

Constructors

Prints()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

dartTypeInfo(DartType dartType) → String
variablesList(List<Variable> variables) → String