Variable class

Available extensions

Constructors

Variable({required String name, DartType? type, String? typeString, bool? isCoreType, bool? isNullable, bool? isFinal, bool? hasRequired, bool? isList, bool? isEnum})

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasRequired → bool?
final
isCoreType → bool?
final
isEnum → bool?
final
isFinal → bool?
final
isList → bool?
final
isNullable → bool?
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → DartType?
final
typeString → String?
final

Methods

copyWith({String? name, String? typeString, DartType? type, bool? isCoreType, bool? isNullable, bool? isFinal, bool? hasRequired, bool? isList, bool? isEnum}) → Variable

Available on Variable, provided by the CopyWith extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited