Strings class

Constructors

Strings()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

empty → String
no setter
entity → String
no setter
mapper → String
no setter
mapperClassName → String
no setter
mapperExtensionName → String
no setter
model → String
no setter
unknown → String
no setter
unnamedClass → String
no setter
unnamedVariable → String
no setter